pub struct DFWasmCompilerOptions {
pub module_name: Option<String>,
pub debugger: bool,
pub skip_nop_debugger: bool,
pub max_template_size: Option<usize>,
pub batch_data_size: Option<usize>,
pub only_include_module_init: bool,
}Expand description
The options for DFWasmCompiler.
Fields
module_name: Option<String>The module name. Useful for when compiling multiple modules.
debugger: boolWhether or not to include debugger function calls.
skip_nop_debugger: boolWhether or not to call the debugger on nops.
max_template_size: Option<usize>Whether or not to limit the size of the templates (highly recommended). Use this to set your plot size.
batch_data_size: Option<usize>Configuration for batching data section memory setters. (i.e. combining multiple set vars into one function call).
If Some, enables batching with the specified number of bytes per batch. Default max is 26 bytes, but 8 may be safer for massive plots.
Using None disables batching.
only_include_module_init: boolWhether or not to only include the module init function in the template. Useful for debugging data section initialization.